==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/ScheduledQueryRuleCriteriaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The rule criteria that defines the conditions of the scheduled query rule.
 * @property allOf A list of conditions to evaluate against the specified scopes
 */
public data class ScheduledQueryRuleCriteriaArgs(
    public val allOf: Output<List<ConditionArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs =
        com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs.builder()
            .allOf(
                allOf?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ScheduledQueryRuleCriteriaArgs].
 */
@PulumiTagMarker
public class ScheduledQueryRuleCriteriaArgsBuilder internal constructor() {
    private var allOf: Output<List<ConditionArgs>>? = null

    /**
     * @param value A list of conditions to evaluate against the specified scopes
     */
    @JvmName("frdxcydpdvifoiul")
    public suspend fun allOf(`value`: Output<List<ConditionArgs>>) {
        this.allOf = value
    }

    @JvmName("wuavemdcgphmnylb")
    public suspend fun allOf(vararg values: Output<ConditionArgs>) {
        this.allOf = Output.all(values.asList())
    }

    /**
     * @param values A list of conditions to evaluate against the specified scopes
     */
    @JvmName("gxissymbbogopmwl")
    public suspend fun allOf(values: List<Output<ConditionArgs>>) {
        this.allOf = Output.all(values)
    }

    /**
     * @param value A list of conditions to evaluate against the specified scopes
     */
    @JvmName("cyjebyhlhvqxmfih")
    public suspend fun allOf(`value`: List<ConditionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    /**
     * @param argument A list of conditions to evaluate against the specified scopes
     */
    @JvmName("bwvjwtbrokfklppy")
    public suspend fun allOf(argument: List<suspend ConditionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ConditionArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument A list of conditions to evaluate against the specified scopes
     */
    @JvmName("sujetkeaqomhhyjb")
    public suspend fun allOf(vararg argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ConditionArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument A list of conditions to evaluate against the specified scopes
     */
    @JvmName("xvkghegwudwfafml")
    public suspend fun allOf(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ConditionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param values A list of conditions to evaluate against the specified scopes
     */
    @JvmName("iaqhbbwlfcqbirhd")
    public suspend fun allOf(vararg values: ConditionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    internal fun build(): ScheduledQueryRuleCriteriaArgs = ScheduledQueryRuleCriteriaArgs(
        allOf = allOf,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/ScheduledQueryRuleCriteriaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The rule criteria that defines the conditions of the scheduled query rule.
 * @property allOf A list of conditions to evaluate against the specified scopes
 */
public data class ScheduledQueryRuleCriteriaArgs(
    public val allOf: Output<List<ConditionArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs =
        com.pulumi.azurenative.insights.inputs.ScheduledQueryRuleCriteriaArgs.builder()
            .allOf(
                allOf?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ScheduledQueryRuleCriteriaArgs].
 */
@PulumiTagMarker
public class ScheduledQueryRuleCriteriaArgsBuilder internal constructor() {
    private var allOf: Output<List<ConditionArgs>>? = null

    /**
     * @param value A list of conditions to evaluate against the specified scopes
     */
    @JvmName("mlinnygdksxhtbrq")
    public suspend fun allOf(`value`: Output<List<ConditionArgs>>) {
        this.allOf = value
    }

    @JvmName("nlypdwbanlkiclwq")
    public suspend fun allOf(vararg values: Output<ConditionArgs>) {
        this.allOf = Output.all(values.asList())
    }

    /**
     * @param values A list of conditions to evaluate against the specified scopes
     */
    @JvmName("nsvegascqiphnlkf")
    public suspend fun allOf(values: List<Output<ConditionArgs>>) {
        this.allOf = Output.all(values)
    }

    /**
     * @param value A list of conditions to evaluate against the specified scopes
     */
    @JvmName("aekrrtupffkrjjxb")
    public suspend fun allOf(`value`: List<ConditionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    /**
     * @param argument A list of conditions to evaluate against the specified scopes
     */
    @JvmName("dfwhotbowmgixdst")
    public suspend fun allOf(argument: List<suspend ConditionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ConditionArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument A list of conditions to evaluate against the specified scopes
     */
    @JvmName("ymrrcqaggmldogcq")
    public suspend fun allOf(vararg argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ConditionArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param argument A list of conditions to evaluate against the specified scopes
     */
    @JvmName("ruhyhxpkgqbsuodv")
    public suspend fun allOf(argument: suspend ConditionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ConditionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allOf = mapped
    }

    /**
     * @param values A list of conditions to evaluate against the specified scopes
     */
    @JvmName("jsqruyucpyjmnsem")
    public suspend fun allOf(vararg values: ConditionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allOf = mapped
    }

    internal fun build(): ScheduledQueryRuleCriteriaArgs = ScheduledQueryRuleCriteriaArgs(
        allOf = allOf,
    )
}
